import { Link, useMatch, useResolvedPath } from "react-router-dom";
import { useTranslation } from 'react-i18next';
import logo_transparent from "./sources/logo_transparent.png";
import { Button } from "@mui/material";
import { ButtonGroup } from "@mui/material";
import i18next from "i18next";


/**
 * Author: Alex Zamastil
 * File contains a navigation bar, situated on the top. This component consisnt of basic navigation and localization selection button.
 */

export default function Navbar() {
  const { t } = useTranslation();
//function for selecting a language
  function changeLanguage(lng) {
    i18next.changeLanguage(lng);
    localStorage.setItem("Localization", lng); 
  }
//file returns a navbar and a button
 return (
    <>
      <nav className="nav">
        <Link to="/welcomePage" className="logo">
          <img src={logo_transparent} className="logo_image" width={200} alt="temp" />
        </Link>
        <ul>
         {/* <CustomLink className="c-link" to="/aboutproject"> <p>{t('about-project')}</p> </CustomLink>*/}

          {localStorage.getItem("token") == null ? (
            <><CustomLink className="loginnav" to="/login"> <p>{t('log-in')}</p> </CustomLink>
              <CustomLink className="registernav" to="/register"> <p>{t('register')}</p> </CustomLink>
            </>

          ) : (<>
            <CustomLink className="c-link" to="/training"> <p> {t("training")}</p> </CustomLink>
            <CustomLink className="c-link" to="/profile"> <p>{t("profile")}</p> </CustomLink>
          </>
          )
          }

        </ul>
          <div className="localizationButton">
        <ButtonGroup 
          orientation="vertical"
          aria-label="Vertical button group"
          variant="outlined"
          size="small"
          color="black"
        >
          <Button onClick={() => changeLanguage("cs")}>CZE</Button>
          <Button onClick={() => changeLanguage("en")}>ENG</Button>
        </ButtonGroup>
        </div>
      </nav>
      <hr className="hr-line" />
    </>
  )
  
}
//CustomLink component renders a custom navigation link with active state based on the current route.
function CustomLink({ to, children, ...props }) {
    // Resolve the path using useResolvedPath hook to handle relative paths and ensure correct URL matching
  const resolvedPath = useResolvedPath(to)
  // Check if the resolved path matches the current route
  const isActive = useMatch({ path: resolvedPath.pathname, end: true })
// Render a list item with active class if the link is active
  return (
    <li className={isActive ? "active" : ""}>
      <Link to={to} {...props}>
        {children}
      </Link>
    </li>
  )
}
